# Views Field View Lazy Load

**Module Name**: `views_field_view_ll`  
**Description**: This module allows you to embed a View as a field in another View.

## Overview

The **Views Field View Lazy Load** module provides the ability to embed a View within a field of another View. It allows
passing argument values from other fields of the parent View to the child View using tokens.

## Features

- Embed a "child" View as a field inside a "parent" View.
- Pass argument values from parent View fields to the child View.
- Token-based argument system for flexibility in embedding data.
- Enable lazy loading of child Views to improve performance.

## Usage Instructions

### Steps to Embed a View as a Field in Another View

1. **Create a child View**: Before adding a View as a field in the parent View, create the child View that you want to
embed.
2. **Add arguments to the child View**: These arguments will be populated by the parent View. Configure them as
necessary (optionally setting validators or handling the "argument not present" state).
3. **Create or edit the parent View**: Ensure the parent View exists, as this will contain the child View field.
4. **Add the child View as a field**: In the parent View, add a field of type `Global: Lazy Loaded View`. Ensure this 
field is placed beneath any fields whose values you plan to pass as arguments.
    - For example, if you want to pass a "node id" from the parent to the child View, add the "node id" field above the 
   `Global: Lazy Loaded View` field in the field list.
5. **Configure child View and Display selection**: After adding the field, choose which child View and Display to use. 
Note that this configuration happens in two steps — the field must first be saved before you can select the Display.
6. **Set up argument tokens**: To pass arguments from the parent View to the child View, locate the "Replacement
patterns" section just below the Arguments setting. Use the listed tokens, separated by commas, as arguments for the
child View.
    - Ensure the fields used for arguments are clean, i.e., without labels, formatting, or extra content, to ensure 
   proper data is passed to the child View.

## Dependencies

This module requires the following Drupal modules:
- `views_field_view`
- `vallb`

## Maintainers

This module is maintained by:
- Nia Kathoni ([nikathone](https://www.drupal.org/u/nikathone))
- Daniel Cothran ([andileco](https://www.drupal.org/u/andileco))
